#
# spec file for package cronopete
#
# Copyright (c) 2016-2017 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cronopete
Version:        4.4.0
Release:        lp150.1.3
Summary:        An Apple's TimeMachine clone for Linux
License:        GPL-3.0
Group:          Productivity/File utilities
Url:            http://www.rastersoft.com
Source:         https://github.com/rastersoft/%{name}/archive/%{_rev}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE cronopete-unset-compiler-flags.patch malcolmlewis@opensuse.org -- Let cmake macros set the compiler flags to use.
Patch0:         cronopete-unset-compiler-flags.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  rsync
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(appindicator3-0.1)
BuildRequires:  pkgconfig(udisks2)
Recommends:     %{name}-lang == %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A backup utility for Linux, modeled after Apple's TimeMachine. It aims to
simplify the creation of periodic backups.

%lang_package
%prep
%setup -q
%patch0 -p1

%build
%cmake \
       -DCMAKE_INSTALL_PREFIX=%{_prefix}
%make_jobs

%install
%cmake_install
# Remove installed docs as we install as %%doc
rm -rf %{buildroot}%{_datadir}/doc
%suse_update_desktop_file %{name}
%find_lang %{name} %{?no_lang_C}
%fdupes -s %{buildroot}

%check
%ctest

%post
%glib2_gsettings_schema_post
%icon_theme_cache_post
%desktop_database_post

%postun
%glib2_gsettings_schema_postun
%icon_theme_cache_postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc COPYING HISTORY.md doc/*
%{_sysconfdir}/xdg/autostart/cronopete.desktop
%{_bindir}/%{name}*
%dir %{_libexecdir}/plugs
%dir %{_libexecdir}/plugs/cronopete
%dir %{_libexecdir}/plugs/cronopete/cronopete
%{_libexecdir}/plugs/cronopete/cronopete/cronopete.plug
%{_datadir}/applications/cronopete_preferences.desktop
%{_datadir}/applications/cronopete_restore.desktop
%{_datadir}/%{name}
%{_datadir}/dbus-1/services/com.rastersoft.cronopete.service
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/icons/hicolor/*/status/*
%{_datadir}/glib-2.0/schemas/org.rastersoft.cronopete.gschema.xml

%files lang -f %{name}.lang

%changelog
* Fri Jul 13 2018 nrochard@gmail.com
  Changes from 4.4.0:
  * Added remote control for unmounting the backup disk
  Changes from 4.3.0:
  * Now allows to unmount the backup drive
  * Now shows more information about the drive when formatting a disk to be used for backup
  * Updated translations
  Changes from 4.2.0:
  * Now only sets low priority to RSYNC itself, not to the whole program
  * Better management of external disks with UDisks2
  * Now the format doesn't fail if it last too much time
  * Fixed french translation (thanks to Maieul)
  * Now doesn't show CDROMs or Squashfs file systems
  Changes from 4.1.1:
  * Allows to open an specific folder to restore files (allows to integrate with file managers)
  * Preliminar integration with Nautilus
  Changes from 4.1.0:
  * Now detects better the external disks
  Changes from version 4.0.1:
  * Updated GL translation
  Changes from version 4.0.0:
  * Code refactorization
  * Now utilizes RSYNC instead of own code
  * Allows to go to a date in the restore interface by clicking in the timeline
  * Shows dates in the timeline when restoring files
  * Now remembers whether the user preffers an icon view or an icon list in the restore window
  * Allows to sort the files and folders in the restore window by clicking on the column name
  * Shows the file type in the restore window and allows to sort by file type
  * Added extra security checks when deleting old backups
  * Now ensures that half-deleted old backups won't interfere with the restoring window, and won't be used as base for a backup
  * Uses the current Gtk fonts in the restore interface
  * Ensures that the main "cronopete" folder is writable by anyone, to allow to use the same disk by several users in the same computer
  * Ensures that the backup folder for each user is readable and writable ONLY by the owner, to ensure security and privacy
  * Now deletes the old backups after doing the backup, not before, to ensure to make the first backup as soon as possible
  * Architecture designed to allow the use of new backends in an easier way
  * Now shows the capacity in GB instead of Gib
  * Uses colors when showing warning and error messages in the log
  * Experimental backend for backing up to a "folder" instead of an "external disk"
  Changes from version 3.27.0:
  * Now ignores backups "from the future" to avoid troubles when creating new backups or listing them
  Changes from version 3.26.2:
  * Added German translation
  Changes from version 3.26.1:
  * Added french translation
* Sat Jul 22 2017 malcolmlewis@opensuse.org
- Updated to version 3.26.0:
  * Code cleanup that should fix the folders with odd names.
- Changes from version 3.25.0:
  * Now shows an error if trying to restore files without the backup
    disk.
  * Translation updates.
- Changes from version 3.24.0:
  * Now the restored file is the original one if there is no file
    with that name in the destination folder.
  * Fixed the bookmarks and the path buttons in the restore
    interface.
  * Now doesn't fail to restore files when the destination folder
    doesn't exist.
- Changes from version 3.23.0:
  * Now supports external drives with blank spaces in their name.
- Changes from version 3.22.0:
  * Now ensures that it doesn't die accidentally.
  * Fixed a coding bug with internal IPC.
- Add cronopete-unset-compiler-flags.patch: Let cmake macros set the
  compiler flags to use.
* Tue Oct 11 2016 malcolmlewis@opensuse.org
- Initial build.
